# 🚀 Quickstart

## 1. Installation

### PyPi

[![PyPI - Version](https://img.shields.io/pypi/v/icland?logo=pypi&logoColor=white&color=blue&style=flat-square)](https://pypi.org/project/icland/)

icland can be installed via [pip](https://pip.pypa.io/en/stable/):

```shell
$ pip install icland
```
